@@ -2,10 +2,9 @@
 
 from typing import Union
 
-from pydantic import BaseModel
-
 from ...store_type import StoreType
 from ...user_event_other_type import UserEventOtherType
+from ..base_model import BaseModel
 
 
 class UserEvent(BaseModel):
@@ -24,6 +23,8 @@ class UserEvent(BaseModel):
         Dictionary of rewards (positive deltas to apply to the user)
     curse: dict[Union[UserEventTypeOther, StoreType], int]
         Dictionary of curses (negative deltas to apply to the user)
+    requirements: dict[Union[UserEventOtherType, StoreType], int]
+        Dictionary of requirements (amounts user must meet to trigger the event)
     """
 
     title: str
@@ -31,3 +32,4 @@ class UserEvent(BaseModel):
     notification: dict[int, str]
     reward: dict[Union[UserEventOtherType, StoreType], int]
     curse: dict[Union[UserEventOtherType, StoreType], int]
+    requirements: dict[Union[UserEventOtherType, StoreType], int]
