@@ -3,6 +3,7 @@
 from typing import Optional
 
 from ...feature_details import FeatureDetails
+from ...feature_type import FeatureType
 from ..base_model import BaseModel
 
 
@@ -14,5 +15,6 @@ class UserFeatureState(BaseModel):
     ----------
     """
 
-    details: FeatureDetails
+    name: Optional[FeatureType]
+    details: Optional[FeatureDetails]
     description: Optional[str]
